@@ -20,46 +20,60 @@ int db_open_rw(const int createifnotfound)
 
 int db_open(const int createifnotfound, const int readonly)
 {
-	int rc, createdb = 0;
 	char dbfilename[530];
 
+	if (strlen(cfg.dbfile) > 0) {
+		strncpy_nt(dbfilename, cfg.dbfile, 530);
+	} else {
 #ifdef CHECK_VNSTAT
-	/* use ram based database when testing for shorter test execution times by reducing disk i/o */
-	snprintf(dbfilename, 530, ":memory:");
-	createdb = 1;
+		/* use ram based database when testing for shorter test execution times by reducing disk i/o */
+		snprintf(dbfilename, 530, ":memory:");
 #else
-	struct stat filestat;
-
-	if (db != NULL) {
-		return 1;
+		snprintf(dbfilename, 530, "%s/%s", cfg.dbdir, DATABASEFILE);
+		strncpy_nt(cfg.dbfile, dbfilename, 530);
+#endif
 	}
 
-	snprintf(dbfilename, 530, "%s/%s", cfg.dbdir, DATABASEFILE);
+	return db_open_filename(dbfilename, createifnotfound, readonly);
+}
 
-	/* create database if file doesn't exist */
-	if (stat(dbfilename, &filestat) != 0) {
-		if (errno == ENOENT && createifnotfound && !readonly) {
-			createdb = 1;
-			if (debug)
-				printf("\"%s\" doesn't exist, creating new database\n", dbfilename);
-		} else {
-			if (debug)
-				printf("Error (debug): Handling database \"%s\" failed: %s\n", dbfilename, strerror(errno));
-			return 0;
-		}
+int db_open_filename(const char *dbfilename, const int createifnotfound, const int readonly)
+{
+	int rc, createdb = 0;
+	struct stat filestat;
+
+	if (strcmp(dbfilename, ":memory:") == 0) {
+		createdb = 1;
 	} else {
-		if (filestat.st_size == 0) {
-			if (createifnotfound) {
+		if (db != NULL) {
+			return 1;
+		}
+
+		/* create database if file doesn't exist */
+		if (stat(dbfilename, &filestat) != 0) {
+			if (errno == ENOENT && createifnotfound && !readonly) {
 				createdb = 1;
 				if (debug)
-					printf("\"%s\" exists but is 0 sized, creating new database\n", dbfilename);
+					printf("\"%s\" doesn't exist, creating new database\n", dbfilename);
 			} else {
-				printf("Error: Database \"%s\" contains 0 bytes and isn't a valid database, exiting.\n", dbfilename);
-				exit(EXIT_FAILURE);
+				if (debug)
+					printf("Error (debug): Handling database \"%s\" failed: %s\n", dbfilename, strerror(errno));
+				return 0;
+			}
+		} else {
+			if (filestat.st_size == 0) {
+				if (createifnotfound) {
+					createdb = 1;
+					if (debug)
+						printf("\"%s\" exists but is 0 sized, creating new database\n", dbfilename);
+				} else {
+					printf("Error: Database \"%s\" contains 0 bytes and isn't a valid database, exiting.\n", dbfilename);
+					exit(EXIT_FAILURE);
+				}
 			}
 		}
 	}
-#endif
+
 	db_errcode = 0;
 	db_intransaction = 0;
 	if (readonly) {
@@ -1325,22 +1339,22 @@ int db_getdata_range(dbdatalist **dbdata, dbdatalistinfo *listinfo, const char *
 			if (resultlimit > 0) {
 				snprintf(limit, 64, "limit %" PRIu32 "", resultlimit);
 			}
-			sqlite3_snprintf(768, sql, "select * from (select id, strftime('%%s', date, 'utc') as unixdate, sum(rx) as rx, sum(tx) as tx from day where interface in (%s) %s %s group by date order by rx+tx desc, unixdate asc %s) order by rx+tx asc, unixdate desc", ifaceidin, dbegin, dend, limit);
+			sqlite3_snprintf(768, sql, "select * from (select id, strftime('%%s', date, 'utc') as unixdate, sum(rx) as rx, sum(tx) as tx, date from day where interface in (%s) %s %s group by date order by rx+tx desc, date asc %s) order by rx+tx asc, date desc", ifaceidin, dbegin, dend, limit);
 		} else {
-			sqlite3_snprintf(768, sql, "select * from (select id, strftime('%%s', date, 'utc') as unixdate, sum(rx) as rx, sum(tx) as tx from top where interface in (%s) group by date order by rx+tx desc, unixdate asc %s) order by rx+tx asc, unixdate desc", ifaceidin, limit);
+			sqlite3_snprintf(768, sql, "select * from (select id, strftime('%%s', date, 'utc') as unixdate, sum(rx) as rx, sum(tx) as tx, date from top where interface in (%s) group by date order by rx+tx desc, date asc %s) order by rx+tx asc, date desc", ifaceidin, limit);
 		}
 	} else if (strcmp(table, "percentile") == 0) {
 		/* 'percentile' is a meta table collected from 'fiveminute' grouped as hours requiring as different query */
 		if (strlen(dbegin) && strlen(limit)) {
-			sqlite3_snprintf(768, sql, "select * from (select id, strftime('%%s', date, 'utc') as unixdate, sum(rx), sum(tx) from fiveminute where interface in (%s) %s %s group by strftime('%%Y-%%m-%%d %%H', date, 'utc') order by unixdate asc %s) order by unixdate desc", ifaceidin, dbegin, dend, limit);
+			sqlite3_snprintf(768, sql, "select * from (select id, strftime('%%s', date, 'utc') as unixdate, sum(rx), sum(tx), date from fiveminute where interface in (%s) %s %s group by strftime('%%Y-%%m-%%d %%H', date, 'utc') order by date asc %s) order by date desc", ifaceidin, dbegin, dend, limit);
 		} else {
-			sqlite3_snprintf(768, sql, "select id, strftime('%%s', date, 'utc') as unixdate, sum(rx), sum(tx) from fiveminute where interface in (%s) %s %s group by strftime('%%Y-%%m-%%d %%H', date, 'utc') order by unixdate desc %s", ifaceidin, dbegin, dend, limit);
+			sqlite3_snprintf(768, sql, "select id, strftime('%%s', date, 'utc') as unixdate, sum(rx), sum(tx) from fiveminute where interface in (%s) %s %s group by strftime('%%Y-%%m-%%d %%H', date, 'utc') order by date desc %s", ifaceidin, dbegin, dend, limit);
 		}
 	} else {
 		if (strlen(dbegin) && strlen(limit)) {
-			sqlite3_snprintf(768, sql, "select * from (select id, strftime('%%s', date, 'utc') as unixdate, sum(rx), sum(tx) from %s where interface in (%s) %s %s group by date order by unixdate asc %s) order by unixdate desc", table, ifaceidin, dbegin, dend, limit);
+			sqlite3_snprintf(768, sql, "select * from (select id, strftime('%%s', date, 'utc') as unixdate, sum(rx), sum(tx), date from %s where interface in (%s) %s %s group by date order by date asc %s) order by date desc", table, ifaceidin, dbegin, dend, limit);
 		} else {
-			sqlite3_snprintf(768, sql, "select id, strftime('%%s', date, 'utc') as unixdate, sum(rx), sum(tx) from %s where interface in (%s) %s %s group by date order by unixdate desc %s", table, ifaceidin, dbegin, dend, limit);
+			sqlite3_snprintf(768, sql, "select id, strftime('%%s', date, 'utc') as unixdate, sum(rx), sum(tx) from %s where interface in (%s) %s %s group by date order by date desc %s", table, ifaceidin, dbegin, dend, limit);
 		}
 	}
 	free(ifaceidin);
@@ -1354,8 +1368,8 @@ int db_getdata_range(dbdatalist **dbdata, dbdatalistinfo *listinfo, const char *
 	}
 
 	rc = sqlite3_column_count(sqlstmt);
-	if (rc != 4) {
-		snprintf(errorstring, 1024, "Get data returned unexpected column count %d instead of 4: \"%s\"", rc, sql);
+	if (rc < 4) {
+		snprintf(errorstring, 1024, "Get data returned unexpected column count %d instead of at least 4: \"%s\"", rc, sql);
 		printe(PT_Error);
 		sqlite3_finalize(sqlstmt);
 		return 0;
