@@ -40,8 +40,9 @@ void cursorshow(void);
 void eraseline(void);
 int validatedatetime(const char *str);
 int issametimeslot(const ListType listtype, const time_t entry, const time_t updated);
-uint64_t getperiodseconds(const ListType listtype, const time_t entry, const time_t updated, const short isongoing);
-void getestimates(uint64_t *rx, uint64_t *tx, const ListType listtype, const time_t updated, dbdatalist **dbdata);
+uint64_t getperiodseconds(const ListType listtype, const time_t entry, const time_t updated, const time_t created, const short isongoing);
+void getestimates(uint64_t *rx, uint64_t *tx, const ListType listtype, const time_t updated, const time_t created, dbdatalist **dbdata);
 int ishelprequest(const char *arg);
+void indent(int i);
 
 #endif
