@@ -1,5 +1,5 @@
 /*
-vnStat - Copyright (C) 2002-2024 Teemu Toivola <tst@iki.fi>
+vnStat - Copyright (C) 2002-2025 Teemu Toivola <tst@iki.fi>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ vnStat - Copyright (C) 2002-2024 Teemu Toivola <tst@iki.fi>
 
 int main(int argc, char *argv[])
 {
-	int currentarg;
+	int currentarg, dbfiledefined = 0;
 	DIR *dir = NULL;
 	PARAMS p;
 
@@ -74,15 +74,26 @@ int main(int argc, char *argv[])
 
 	parseargs(&p, argc, argv);
 
+	/* bypass normal database handling as databases for merge are provided from command line */
+	if (p.merge) {
+		handlemerge(&p);
+		return 0;
+	}
+
 	/* open database and see if it contains any interfaces */
 	if (!p.traffic && !p.livetraffic) {
-		if ((dir = opendir(cfg.dbdir)) != NULL) {
-			if (debug)
-				printf("Dir OK\n");
-			closedir(dir);
+		if (strlen(cfg.dbfile) > 0) {
+			dbfiledefined = 1;
+		}
+		if (dbfiledefined || (dir = opendir(cfg.dbdir)) != NULL) {
+			if (dir != NULL) {
+				if (debug)
+					printf("Dir OK\n");
+				closedir(dir);
+			}
 			if (!db_open_ro()) {
-				printf("Error: Failed to open database \"%s/%s\" in read-only mode.\n", cfg.dbdir, DATABASEFILE);
-				if (errno == ENOENT) {
+				printf("Error: Failed to open database \"%s\" in read-only mode: %s\n", cfg.dbfile, strerror(errno));
+				if (!dbfiledefined && errno == ENOENT) {
 					printf("The vnStat daemon should have created the database when started.\n");
 					printf("Check that it is configured and running. See also \"man vnstatd\".\n");
 				}
