@@ -1,5 +1,5 @@
 /*
-vnStat image output - Copyright (C) 2007-2024 Teemu Toivola <tst@iki.fi>
+vnStat image output - Copyright (C) 2007-2025 Teemu Toivola <tst@iki.fi>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@ vnStat image output - Copyright (C) 2007-2024 Teemu Toivola <tst@iki.fi>
 #include "image.h"
 #include "cfg.h"
 #include "misc.h"
+#include "clicommon.h"
 #include "vnstati.h"
 
 int main(int argc, char *argv[])
@@ -158,6 +159,8 @@ void showihelp(const IPARAMS *p)
 	printf("      -D,  --debug                       show some additional debug information\n");
 	printf("      -v,  --version                     show version\n");
 	printf("      --limit <limit>                    set list entry limit\n");
+	printf("      --db <file>                        select database file\n");
+	printf("      --dbiflist [mode]                  show list of interfaces in database\n");
 	printf("      --dbdir <directory>                select database directory\n");
 	printf("      --style <mode>                     select output style (0-3)\n");
 	printf("      --locale <locale>                  set locale\n");
@@ -271,7 +274,17 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 				if (debug)
 					printf("Transparency changed: %d\n", cfg.transbg);
 			}
-		} else if ((strcmp(argv[currentarg], "--dbdir")) == 0) {
+		} else if ((strcmp(argv[currentarg], "--db") == 0) || (strcmp(argv[currentarg], "--dbfile") == 0)) {
+			if (currentarg + 1 < argc) {
+				strncpy_nt(cfg.dbfile, argv[currentarg + 1], 530);
+				if (debug)
+					printf("DatabaseFile: \"%s\"\n", cfg.dbfile);
+				currentarg++;
+			} else {
+				fprintf(stderr, "Error: File for %s missing.\n", argv[currentarg]);
+				exit(EXIT_FAILURE);
+			}
+		} else if (strcmp(argv[currentarg], "--dbdir") == 0) {
 			if (currentarg + 1 < argc) {
 				strncpy_nt(cfg.dbdir, argv[currentarg + 1], 512);
 				if (debug)
@@ -281,7 +294,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 				fprintf(stderr, "Error: Directory for --dbdir missing.\n");
 				exit(EXIT_FAILURE);
 			}
-		} else if ((strcmp(argv[currentarg], "--locale")) == 0) {
+		} else if (strcmp(argv[currentarg], "--locale") == 0) {
 			if (currentarg + 1 < argc) {
 				setlocale(LC_ALL, argv[currentarg + 1]);
 				if (debug)
@@ -294,7 +307,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 		} else if (strcmp(argv[currentarg], "--config") == 0) {
 			/* config has already been parsed earlier so nothing to do here */
 			currentarg++;
-		} else if ((strcmp(argv[currentarg], "--headertext")) == 0) {
+		} else if (strcmp(argv[currentarg], "--headertext") == 0) {
 			if (currentarg + 1 < argc) {
 				strncpy_nt(ic->headertext, argv[currentarg + 1], 65);
 				if (debug)
@@ -545,6 +558,23 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 				if (debug)
 					printf("Invert colors changed: %d\n", ic->invert);
 			}
+		} else if (strcmp(argv[currentarg], "--dbiflist") == 0) {
+			cfg.qmode = 0;
+			if (currentarg + 1 < argc && (strlen(argv[currentarg + 1]) == 1 || ishelprequest(argv[currentarg + 1]))) {
+				if (!isdigit(argv[currentarg + 1][0]) || atoi(argv[currentarg + 1]) > 2 || atoi(argv[currentarg + 1]) < 0) {
+					if (!ishelprequest(argv[currentarg + 1]))
+						printf("Error: Invalid mode parameter \"%s\".\n", argv[currentarg + 1]);
+					printf(" Valid parameters for --dbiflist:\n");
+					printf("    0 - show verbose (default)\n");
+					printf("    1 - show one interface per line\n");
+					printf("    2 - show only interface count\n");
+					exit(EXIT_FAILURE);
+				}
+				cfg.qmode = atoi(argv[currentarg + 1]);
+				currentarg++;
+			}
+			showdbiflist(cfg.qmode);
+			exit(EXIT_SUCCESS);
 		} else if ((strcmp(argv[currentarg], "-v") == 0) || (strcmp(argv[currentarg], "--version")) == 0) {
 			printf("vnStat image output %s by Teemu Toivola <tst at iki dot fi> (SQLite %s, LibGD %d.%d.%d)\n", getversion(), sqlite3_libversion(), GD_MAJOR_VERSION, GD_MINOR_VERSION, GD_RELEASE_VERSION);
 			exit(EXIT_SUCCESS);
@@ -632,7 +662,7 @@ void handledatabase(IPARAMS *p, IMAGECONTENT *ic)
 	iflist *dbifl = NULL;
 
 	if (!db_open_ro()) {
-		fprintf(stderr, "Error: Failed to open database \"%s/%s\" in read-only mode.\n", cfg.dbdir, DATABASEFILE);
+		fprintf(stderr, "Error: Failed to open database \"%s\" in read-only mode: %s\n", cfg.dbfile, strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	if (strlen(p->interface)) {
