@@ -9,12 +9,12 @@ typedef struct {
 } IPARAMS;
 
 void initiparams(IPARAMS *p);
-void showihelp(IPARAMS *p);
+void showihelp(const IPARAMS *p);
 void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv);
-void validateinput(IPARAMS *p);
-void handlecaching(IPARAMS *p, IMAGECONTENT *ic);
+void validateinput(const IPARAMS *p);
+void handlecaching(const IPARAMS *p, const IMAGECONTENT *ic);
 void handledatabase(IPARAMS *p, IMAGECONTENT *ic);
-void validateoutput(IPARAMS *p);
+void validateoutput(const IPARAMS *p);
 void writeoutput(IPARAMS *p, IMAGECONTENT *ic);
 #if HAVE_DECL_GDIMAGEFILE
 void showsupportedfileextensions(void);
