@@ -891,6 +891,51 @@ START_TEST(showalert_can_alert_on_limit_and_show_things)
 }
 END_TEST
 
+START_TEST(showalert_can_alert_on_limit_and_show_things_with_correct_return_value)
+{
+	int ret;
+
+	defaultcfg();
+	suppress_output();
+
+	ret = db_open_rw(1);
+	ck_assert_int_eq(ret, 1);
+
+	ret = db_addinterface("something");
+	ck_assert_int_eq(ret, 1);
+
+	ret = db_setalias("something", "anything");
+	ck_assert_int_eq(ret, 1);
+
+	ret = db_addtraffic("something", 1000, 2000);
+	ck_assert_int_eq(ret, 1);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Hour, AC_Total, 2500);
+	ck_assert_int_eq(ret, 2);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Day, AC_Total, 2500);
+	ck_assert_int_eq(ret, 2);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Month, AC_Total, 2500);
+	ck_assert_int_eq(ret, 2);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_Total, 2500);
+	ck_assert_int_eq(ret, 2);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Percentile, AC_RX, 2);
+	ck_assert_int_eq(ret, 2);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Percentile, AC_TX, 4);
+	ck_assert_int_eq(ret, 2);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Percentile, AC_Total, 5);
+	ck_assert_int_eq(ret, 2);
+
+	ret = db_close();
+	ck_assert_int_eq(ret, 1);
+}
+END_TEST
+
 START_TEST(showalert_can_alert_on_limit_and_show_things_in_json)
 {
 	int ret;
@@ -937,6 +982,52 @@ START_TEST(showalert_can_alert_on_limit_and_show_things_in_json)
 }
 END_TEST
 
+START_TEST(showalert_can_alert_on_limit_and_show_things_in_json_with_correct_return_value)
+{
+	int ret;
+
+	defaultcfg();
+	cfg.qmode = 10;
+	suppress_output();
+
+	ret = db_open_rw(1);
+	ck_assert_int_eq(ret, 1);
+
+	ret = db_addinterface("something");
+	ck_assert_int_eq(ret, 1);
+
+	ret = db_setalias("something", "anything");
+	ck_assert_int_eq(ret, 1);
+
+	ret = db_addtraffic("something", 1000, 2000);
+	ck_assert_int_eq(ret, 1);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Hour, AC_Total, 2500);
+	ck_assert_int_eq(ret, 2);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Day, AC_Total, 2500);
+	ck_assert_int_eq(ret, 2);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Month, AC_Total, 2500);
+	ck_assert_int_eq(ret, 2);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_Total, 2500);
+	ck_assert_int_eq(ret, 2);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Percentile, AC_RX, 2);
+	ck_assert_int_eq(ret, 2);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Percentile, AC_TX, 4);
+	ck_assert_int_eq(ret, 2);
+
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Percentile, AC_Total, 5);
+	ck_assert_int_eq(ret, 2);
+
+	ret = db_close();
+	ck_assert_int_eq(ret, 1);
+}
+END_TEST
+
 START_TEST(showalert_limit_and_conditions_matter)
 {
 	int ret;
@@ -956,33 +1047,63 @@ START_TEST(showalert_limit_and_conditions_matter)
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_Total, 100);
 	ck_assert_int_eq(ret, 1);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_Total, 100);
+	ck_assert_int_eq(ret, 2);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_Total, 280);
 	ck_assert_int_eq(ret, 1);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_Total, 280);
+	ck_assert_int_eq(ret, 2);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_Total, 350);
 	ck_assert_int_eq(ret, 0);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_Total, 350);
+	ck_assert_int_eq(ret, 0);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_Total, 300);
 	ck_assert_int_eq(ret, 0);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_Total, 300);
+	ck_assert_int_eq(ret, 0);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_RX, 80);
 	ck_assert_int_eq(ret, 1);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_RX, 80);
+	ck_assert_int_eq(ret, 2);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_RX, 150);
 	ck_assert_int_eq(ret, 0);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_RX, 150);
+	ck_assert_int_eq(ret, 0);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_TX, 180);
 	ck_assert_int_eq(ret, 1);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_TX, 180);
+	ck_assert_int_eq(ret, 2);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_TX, 250);
 	ck_assert_int_eq(ret, 0);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_TX, 250);
+	ck_assert_int_eq(ret, 0);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_TX, 350);
 	ck_assert_int_eq(ret, 0);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_TX, 350);
+	ck_assert_int_eq(ret, 0);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_TX, 200);
 	ck_assert_int_eq(ret, 0);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_TX, 200);
+	ck_assert_int_eq(ret, 0);
+
 	ret = db_close();
 	ck_assert_int_eq(ret, 1);
 }
@@ -1008,33 +1129,63 @@ START_TEST(showalert_limit_and_conditions_matter_also_for_json_output)
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_Total, 100);
 	ck_assert_int_eq(ret, 1);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_Total, 100);
+	ck_assert_int_eq(ret, 2);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_Total, 280);
 	ck_assert_int_eq(ret, 1);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_Total, 280);
+	ck_assert_int_eq(ret, 2);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_Total, 350);
 	ck_assert_int_eq(ret, 0);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_Total, 350);
+	ck_assert_int_eq(ret, 0);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_Total, 300);
 	ck_assert_int_eq(ret, 0);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_Total, 300);
+	ck_assert_int_eq(ret, 0);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_RX, 80);
 	ck_assert_int_eq(ret, 1);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_RX, 80);
+	ck_assert_int_eq(ret, 2);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_RX, 150);
 	ck_assert_int_eq(ret, 0);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_RX, 150);
+	ck_assert_int_eq(ret, 0);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_TX, 180);
 	ck_assert_int_eq(ret, 1);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_TX, 180);
+	ck_assert_int_eq(ret, 2);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_TX, 250);
 	ck_assert_int_eq(ret, 0);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_TX, 250);
+	ck_assert_int_eq(ret, 0);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_TX, 350);
 	ck_assert_int_eq(ret, 0);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_TX, 350);
+	ck_assert_int_eq(ret, 0);
+
 	ret = showalert("something", AO_Always_Output, AE_Exit_1_On_Limit, AT_Year, AC_TX, 200);
 	ck_assert_int_eq(ret, 0);
 
+	ret = showalert("something", AO_Always_Output, AE_Exit_2_On_Limit, AT_Year, AC_TX, 200);
+	ck_assert_int_eq(ret, 0);
+
 	ret = db_close();
 	ck_assert_int_eq(ret, 1);
 }
@@ -1079,7 +1230,9 @@ void add_database_tests(Suite *s)
 	tcase_add_test(tc_db, showalert_shows_nothing_with_none_type);
 	tcase_add_test(tc_db, showalert_shows_nothing_in_json_with_none_type);
 	tcase_add_test(tc_db, showalert_can_alert_on_limit_and_show_things);
+	tcase_add_test(tc_db, showalert_can_alert_on_limit_and_show_things_with_correct_return_value);
 	tcase_add_test(tc_db, showalert_can_alert_on_limit_and_show_things_in_json);
+	tcase_add_test(tc_db, showalert_can_alert_on_limit_and_show_things_in_json_with_correct_return_value);
 	tcase_add_test(tc_db, showalert_limit_and_conditions_matter);
 	tcase_add_test(tc_db, showalert_limit_and_conditions_matter_also_for_json_output);
 	suite_add_tcase(s, tc_db);
